@@ -1,8 +1,3 @@
-#.onLoad <- function(library, section) {
-#   require("methods")
-#   require("TSdbi")
-#   require("RPostgreSQL")
-#   }
 
 setClass("TSPostgreSQLConnection", 
    contains=c("PostgreSQLConnection", "conType", "TSdb")) 
@@ -30,21 +25,24 @@ setMethod("TSconnect",   signature(drv="PostgreSQLDriver", dbname="character"),
 
 setMethod("TSput",   signature(x="ANY", serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(x, serIDs, con=getOption("TSconnection"), Table=NULL, 
-       TSdescription.=TSdescription(x), TSdoc.=TSdoc(x), TSlabel.=TSlabel(x),  
+       TSdescription.=TSdescription(x), TSdoc.=TSdoc(x), TSlabel.=TSlabel(x),
+       TSsource.=TSsource(x),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
   TSdbi:::TSputSQL(x, serIDs, con, Table=Table, 
-   TSdescription.=TSdescription., TSdoc.=TSdoc., TSlabel.=TSlabel., 
+   TSdescription.=TSdescription., TSdoc.=TSdoc., TSlabel.=TSlabel.,
+    TSsource.=TSsource.,
    vintage=vintage, panel=panel) )
 
 setMethod("TSget",   signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"), 
        TSrepresentation=getOption("TSrepresentation"),
-       tf=NULL, start=tfstart(tf), end=tfend(tf),
-       names=NULL, TSdescription=FALSE, TSdoc=FALSE, TSlabel=FALSE,
+       tf=NULL, start=tfstart(tf), end=tfend(tf), names=NULL, 
+       TSdescription=FALSE, TSdoc=FALSE, TSlabel=FALSE, TSsource=TRUE,
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
    TSdbi:::TSgetSQL(serIDs, con, TSrepresentation=TSrepresentation,
-       tf=tf, start=start, end=end,
-       names=names, TSdescription=TSdescription, TSdoc=TSdoc, TSlabel=TSlabel,
+       tf=tf, start=start, end=end, names=names, 
+       TSdescription=TSdescription, TSdoc=TSdoc, TSlabel=TSlabel,
+         TSsource=TSsource,
        vintage=vintage, panel=panel) )
 
 setMethod("TSdates",    signature(serIDs="character", con="TSPostgreSQLConnection"),
@@ -65,6 +63,10 @@ setMethod("TSlabel",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
         TSdbi:::TSlabelSQL(x=x, con=con) )
 
+setMethod("TSsource",   signature(x="character", con="TSPostgreSQLConnection"),
+   definition= function(x, con=getOption("TSconnection"), ...)
+        TSdbi:::TSsourceSQL(x=x, con=con) )
+
 setMethod("TSdelete", signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
    vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
